<template>
  <basic-container>
    <v-chart id="chart" :auto-resize="true" :options="chartOptions"></v-chart>
  </basic-container>
</template>

<script>
import 'echarts'
import 'echarts/lib/chart/line'
import 'echarts/lib/chart/pie'
import 'echarts/lib/chart/bar'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/legend'

export default {
  name: "mixCart",
  props: {
    mixData: {
      type: Array,
      default: []
    },
    chartName: {
      type: String,
      default: ""
    }
  },
  data() {
    return {
      chartOptions: {
        title: {
          text: "",
        },
        grid: {
          left: "3%",
          right: "4%",
          bottom: "3%",
          containLabel: true,
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
          },
        },
        legend: {
          data: ["总量", "新增"],
          left: "center",
          textStyle: {
            fontSize: 14 // 调整字体大小
          }
        },
        xAxis: {
          type: "category",
          data: [
            "一月",
            "二月",
            "三月",
            "四月",
            "五月",
            "六月",
            "七月",
            "八月",
            "九月",
            "十月",
            "十一月",
            "十二月",
          ],
        },
        yAxis: {
          type: "value",
        },
        series: [],
      },
    };
  },
  watch: {
    mixData: {
      immediate: true,
      handler(newval, oldval) {
        if (newval) {
          const colors = ["#2eadd6", "#db3c3c"];

          const seriesData = newval.map((data, index) => ({
            name: index === 0 ? "总量" : "新增",
            type: index === 0 ? "bar" : "line",
            stack: index === 0 ? "总量" : null,
            data: data.map(value => ({value})),
            barWidth: 68,
            label: {
              show: true,
              position: "top"
            },
            itemStyle: {
              color: colors[index]
            },
            emphasis: {
              focus: "series"
            }
          }));

          this.chartOptions.series = seriesData;
        }
      },
    },
    chartName:{
      handler(newval,oldval){
        if(newval){
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate:true,
      deep:true
    }
  },
};
</script>

<style scoped lang="scss">
#chart {
  width: 100%;
  height: 560px;
}
</style>
